import greenfoot.*;

// Icon class: creates objects to display during pawn promotion that can be clicked on to determine the piece desired to promote to
public class Icon extends Actor
{
    String piece = ""; // to hold the String representation of the piece the icon displays
    int square = -1; // to hold the number of the square that the pawn is promoted on
    boolean mouseOn = false; // set true when mouse hovers over this icon, else false
    
    // Icon(int, int) - constructor of Icon.class object - takes a square number (0 to 63) and an icon number(0 to 3)
    // saves pertinent information and calls updateImage() to create the image for the object
    // The icon number determines what type of piece the icon is to display
    public Icon(int sq, int iconNum)
    {
        square = sq; // saves the square number a piece is being promoted on
        String who = (square < 32) ? "w" : "b"; // creates a String representation of who is having a piece promoted
        String pcs = ("w".equals(who)) ? "QRBN" : "qrbn"; // creates a String to list possible pieces to promote to
        piece += pcs.charAt(iconNum); // gets a String representation of the piece this icon should display
        updateImage(); // creates the image for this object
    }
    
    // updateImage() creates or updates the image for the icon object
    private void updateImage()
    {
        String pceStr = "" + (char) ("KQRBNPkqrbnp".indexOf(piece) + 9812); // creates a String whose one character has the image of the piece
        GreenfootImage img = new GreenfootImage(pceStr, 36, Color.BLACK, new Color(0, 0, 0, 0)); // creates the piece image
        img.scale(37, 37); // sizes the piece image
        GreenfootImage back = new GreenfootImage(37, 37); // creates the base image; to be the main image of the object
        Color backColor = ((square % 8) + (square / 8)) == 0 ? Color.LIGHT_GRAY : Color.GRAY; // gets backgound color of square
        Color color = (mouseOn) ? Color.YELLOW : backColor; // determines background color of main image
        back.setColor(color); // sets the background color to the image
        back.fill(); // fills the background
        back.drawImage(img, 0, 0); // adds the piece image to the main image
        back.setColor(Color.BLACK); // sets the line color
        back.drawRect(1, 1, 35, 35); // draws a frame around the piece image on the main image
        setImage(back); // sets the image of the object to that of the main image
    }        
    
    // addedToWorld(World) used only to set the location of the icon object
    public void addedToWorld(World world)
    {
        int x = square % 8, y = (square - x) / 8; // determines the coordinates of the square pawn is being promoted on
        int iconNum = "QRBNqrbn".indexOf("" + piece) % 4; // calculates the icon number
        setLocation(x * 75 + (iconNum % 2) * 37 + 18, y * 75 + ((iconNum - (iconNum % 2)) / 2) * 37 + 18); // places the icon properly in the square
    }

    // act() checks and acts on mouse hovering and clicking
    public void act() 
    {
        if (Greenfoot.mouseMoved(null))
        { // mouse has moved
            if (!mouseOn && Greenfoot.mouseMoved(this)) // mouse moves on
            { // mouse not found previously over this object and now is found over it
                mouseOn = true; // flags mouse found over this object
                updateImage(); // update the image of this icon (to reflect mouse hovering over)
            }
            if (mouseOn && !Greenfoot.mouseMoved(this)) // mouse moves off
            { // mouse was previously over this object and now is found not over it
                mouseOn = false; // flags mouse found not over this object
                updateImage(); // update the image of this icon (to reflect mouse not hovering over)
            }
        }
        if (Greenfoot.mouseClicked(this)) // icon gets selected
        { // mouse button released while on this icon
            Board board = (Board) getWorld(); // get reference to the world
            board.removeObjects(board.getObjects(Icon.class)); // removes the promotion icons from the world
            board.changePromotion(square, piece); // changes the current piece on the promotion square to piece of icon selected
        }
    }    
}
