import greenfoot.*;

// InfoFrame class: used to display title, author and game moves
public class InfoFrame extends Actor
{
    public InfoFrame()
    {
        updateImage();        
    }
    
    //updateImage() creates the image of the frame that contains the list of games moves played so far
    public void updateImage()
    {
        GreenfootImage img = new GreenfootImage(440, 600); // creates the base image; to become the main image
        img.setColor(Color.WHITE); // sets main background color
        img.fill(); // fills background
        img.setColor(Color.PINK); // sets background color for column headers (for player colors text)
        img.fillRect(0, 20, 440, 20); // fills column header background
        img.setColor(Color.CYAN); // sets row header background (for move numbers text)
        img.fillRect(0, 40, 40, 539); // fills row header background
        GreenfootImage top = new GreenfootImage(440, 20); // creates title bar image
        top.setColor(Color.CYAN); // sets background color of title bar image
        top.fill(); // fills title bar background
        String titleText = "CHESS: Drag & Drop                                  by danpost"; // creates title text String
        GreenfootImage title = new GreenfootImage(titleText, 24, Color.BLACK, new Color(0, 0, 0, 0)); // creates title text image
        top.drawImage(title, (top.getWidth() - title.getWidth()) / 2, (top.getHeight() - title.getHeight()) / 2); // add title text image to title bar image
        img.drawImage(top, 0, 0); // adds title bar image to main image
        img.setColor(Color.BLACK); // set line drawing color
        img.drawLine(0, 20, 439, 20); // draws line under title bar
        img.drawLine(0, 40, 439, 40); // draws line under column header
        img.drawRect(0, 0, 1, 600); // draws seperator line between chessboard and information panel
        img.drawLine(40, 20, 40, 569); // draws line between first two columns
        img.drawLine(240, 20, 240, 569); // draws line between second and third columns
        img.drawLine(0, 569, 440, 569); // draws line at bottom of columns
        GreenfootImage head1 = new GreenfootImage("Mv#", 24, Color.BLACK, new Color(0, 0, 0, 0)); // creates column one header text image
        GreenfootImage head2 = new GreenfootImage("WHITE", 24, Color.BLACK, new Color(0, 0, 0, 0)); // creates column two header text image
        GreenfootImage head3 = new GreenfootImage("BLACK", 24, Color.BLACK, new Color(0, 0, 0, 0)); // creates column three header text image
        GreenfootImage header = new GreenfootImage(440, 20); // creates header image
        header.drawImage(head1, (40 - head1.getWidth()) / 2, (header.getHeight() - head1.getHeight()) / 2); // adds column one header text image to header image
        header.drawImage(head2, 110, (header.getHeight() - head2.getHeight()) / 2); // adds column two header text image to header image
        header.drawImage(head3, 310, (header.getHeight() - head3.getHeight()) / 2); // adds column three header text image to header image
        img.drawImage(header, 0, 20); // adds header to main image
        int bottomIndex = (getWorld() != null) ? ((Board) getWorld()).moveCount : 0; // calculates to last move index to display
        int topIndex = (bottomIndex > 47) ? (bottomIndex + 2 - (bottomIndex % 2)) - 48 : 0; // calculates to first move index to display
        for (int i = 0; i < bottomIndex - topIndex; i++)
        { // for each move to display
            if (i > 47) break; // move columns are filled, do not try to display any more (there should not be any more)
            int row = (i - (i % 2)) / 2; // determines how far down to display the move in the move listing
            Board board = (Board) getWorld(); // gets a reference to the world
            String mvStr = "" + board.movers.charAt(topIndex + i) + board.gameMoves[topIndex + i]; // creates the move string to display
            GreenfootImage move = new GreenfootImage(mvStr, 28, Color.BLACK, new Color(0, 0, 0, 0)); // creates the move string image
            if (i % 2 == 0)
            { // white's move
                GreenfootImage index = new GreenfootImage("" + (topIndex / 2 + row + 1), 28, Color.BLACK, new Color(0, 0, 0, 0)); // creates column one text image
                img.drawImage(index, 40 - index.getWidth(), 40 + row * 21); // adds column one text image (move number) to main image
                img.drawImage(move, 45, 40 + row * 21); // adds white's move string image to main image
            }
            else
            { // black's move
                img.drawImage(move, 245, 40 + row * 21); // adds black's move string image to main image
            }
        }
        setImage(img); // sets the InfoFrame image to be that of the main image
    }
}